@@ -132,6 +132,33 @@ class GoldenTestCase(UCTestCase):
     def generate_golden(self):
         raise NotImplementedError()
 
+class InteractiveExecutableReturnValueTestCase(UCTestCase):
+    def execute(self, parameters, exe, inputs, path="/autograder/source/build/"):
+        args = [path + exe]
+        args.extend(parameters)
+
+        try:
+            exe = subprocess.Popen(args,
+                                stdin=subprocess.PIPE,
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.PIPE,
+                                universal_newlines=True,)
+        except OSError:
+            return -1
+        lined_inputs = [ x + "\n" for x in inputs]
+        exe.stdin.write("".join(lined_inputs))
+        exe.stdin.flush()
+        _ = exe.stdout.read()
+
+        try:
+            exe.wait(10)
+            retval = exe.returncode
+            exe.terminate()
+            return retval
+        except subprocess.TimeoutExpired:
+            exe.terminate()
+            return -1
+
 
 class ExecutableTestCase(UCTestCase):
     def execute(self, parameters, exe, path="/autograder/source/build/"):
@@ -164,4 +191,10 @@ class InteractiveExecutableTestCase(UCTestCase):
         return output
 
 class InteractiveExecutableGoldenTestCase(InteractiveExecutableTestCase, GoldenTestCase):
-    pass
\ No newline at end of file
+    pass
+
+class InteractiveExecutableOutputMatchTestCase(InteractiveExecutableTestCase, StringContentsMatchTestCase):
+    def count_output_matches(self, parameters, exe, inputs, match, path="/autograder/source/"):
+        """ Count how many times match matches the text in the output of _exe_ given input _inputs_. """
+        executable_output = self.execute(parameters, exe, inputs, path)
+        return self.count_matches(executable_output, match)
